@@ -33,4 +33,20 @@ test_that("prob_metrics for sf objects", {
     roc_auc(two_class_example, truth, Class1),
     roc_auc(two_class_example_sf, truth, Class1)
   )
+  ### multiclass metrics (not really relevant for SDMs)
+  multi_class_example <- hpc_cv
+  multi_class_example_sf <- multi_class_example
+  multi_class_example_sf$X <- sample(1:5, nrow(multi_class_example_sf), replace = T)
+  multi_class_example_sf$Y <- sample(1:5, nrow(multi_class_example_sf), replace = T)
+  multi_class_example_sf <- sf::st_as_sf(multi_class_example_sf, coords = c("X", "Y"))
+  expect_identical(
+    roc_aunp(multi_class_example, obs, VF:L),
+    roc_aunp(multi_class_example_sf, obs, VF:L)
+  )
+  expect_identical(
+    roc_aunu(multi_class_example, obs, VF:L),
+    roc_aunu(multi_class_example_sf, obs, VF:L)
+  ) 
+  
+  
 })
